@@ -5,7 +5,7 @@ package Data::Frame::Autobox;
 use strict;
 use warnings;
 
-our $VERSION = '0.0052_01'; # TRIAL VERSION
+our $VERSION = '0.0059_01'; # TRIAL VERSION
 
 use parent 'autobox';
 
@@ -143,11 +143,6 @@ sub values {
     [ CORE::values %$hash ];
 }
  
-sub slice {
-    my ($hash, $keys) = @_;
-    return [ @{$hash}{@$keys} ];
-}
-
 
 sub copy { { %{ $_[0] } } }
 
@@ -178,7 +173,7 @@ Data::Frame::Autobox - Autobox arrays and hashes for Data::Frame
 
 =head1 VERSION
 
-version 0.0052_01
+version 0.0059_01
 
 =head1 SYNOPSIS
 
@@ -287,6 +282,10 @@ Returns a boolean value for if the hash ref is empty.
 
     my $sliced_hash = $hash->hslice($keys);
 
+=head2 slice
+
+This is same as C<hslice>.
+
 =head2 at
 
     my $value = $hash->at($key);
@@ -317,10 +316,6 @@ This is same as C<keys>.
 
 Explicitly returns an array.
 
-=head2 slice
-
-    my $values = $hash->slice($keys);
-
 =head2 copy
 
 Shallow copy.
@@ -368,7 +363,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014, 2019 by Zakariyya Mughal, Stephan Loyd.
+This software is copyright (c) 2014, 2019-2021 by Zakariyya Mughal, Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
