@@ -154,7 +154,7 @@ Data::Frame::PDL - A mixin to add some methods to PDL
 
 =head1 VERSION
 
-version 0.0052_01
+version 0.0059_01
 
 =head1 DESCRIPTION
 
@@ -174,7 +174,7 @@ Returns the length of the first dimension.
 
 =head2 diff
 
-    length($lag=1)
+    diff($lag=1)
 
 =head2 flatten
 
@@ -230,7 +230,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014, 2019 by Zakariyya Mughal, Stephan Loyd.
+This software is copyright (c) 2014, 2019-2021 by Zakariyya Mughal, Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
