@@ -107,7 +107,7 @@ Data::Frame::Partial::Sugar - Partial class for data frame syntax sugar
 
 =head1 VERSION
 
-version 0.0052_01
+version 0.0059_01
 
 =head1 SYNOPSIS
 
@@ -123,6 +123,9 @@ version 0.0052_01
 
 =head1 DESCRIPTION
 
+Do not use this module in your code. This is only internally used by
+L<Data::Frame>.
+
 =head1 SEE ALSO
 
 L<Data::Frame>
@@ -143,7 +146,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014, 2019 by Zakariyya Mughal, Stephan Loyd.
+This software is copyright (c) 2014, 2019-2021 by Zakariyya Mughal, Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
