@@ -29,6 +29,11 @@ use Data::Frame::Autobox ();
 use Role::Tiny ();
 Role::Tiny->apply_roles_to_package( 'PDL', 'Data::Frame::PDL' );
 
+# PDL versions between 2.040 and 2.054 has not PDL::Core::at_c
+unless (defined &PDL::Core::at_c) {
+    *PDL::Core::at_c = \&{"PDL::Core::at_bad_c"};
+}
+
 sub import {
     my ( $class, @tags ) = @_;
 
@@ -100,7 +105,7 @@ Data::Frame::Setup - Import stuffs into Data::Frame classes
 
 =head1 VERSION
 
-version 0.0052_01
+version 0.0059_01
 
 =head1 SYNOPSIS
 
@@ -132,7 +137,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014, 2019 by Zakariyya Mughal, Stephan Loyd.
+This software is copyright (c) 2014, 2019-2021 by Zakariyya Mughal, Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
